##  Exporting Transformation Items Via Excel File
To export transformations in the administration area, do the following:
  1. Navigate to the Transformations section in the Administration area.
  2. Go to the Excel Import & Export tab.
  3. Click Export on the Export Transformation tile.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio4d50a0d5a7b7441d8f9d9c2176a7344e_LowRes.png)
Exporting Transformations from the Administration Area


This exports all your existing transformation items into an Excel file. The exported file also serves as a template for importing data, as it’s properly structured with separate sheets for each transformation type and includes all the required fields as columns.
You can also export the transformations from the transformation explorer, and this option is available for both admins and non-admin users.
To export from the transformation explorer, do the following:
  1. In the Inventory, filter for a particular fact sheet type.
  2. On the right side panel, under the Additional Resources section, click Transformations Explorer.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio39ff3d5e6b444bd0a951894632d1f211_LowRes.png)
Opening Transformation Explorer from the Inventory
  3. You can apply filters to just export some transformations by clicking the +Add Filter button and selecting the filters.
  4. In the upper-right corner of the transformations explorer page, click Export to Excel.
  5. In the resulting outlay, click Export.


**Tip**
When exporting from the transformation explorer, you can apply filters to export specific transformations, such as by transformation type or completion date, and more.
